==> mcp_dbutils-0.20.0.tar.gz: mcp_dbutils-0.20.0/README_AR.md <==
<div dir="rtl">

# أدوات قواعد بيانات MCP

<!-- شارات حالة المشروع -->
[![حالة البناء](https://img.shields.io/github/workflow/status/donghao1393/mcp-dbutils/Quality%20Assurance?label=tests)](https://github.com/donghao1393/mcp-dbutils/actions)
[![التغطية](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/donghao1393/bdd0a63ec2a816539ff8c136ceb41e48/raw/coverage.json)](https://github.com/donghao1393/mcp-dbutils/actions)
[![حالة بوابة الجودة](https://sonarcloud.io/api/project_badges/measure?project=donghao1393_mcp-dbutils&metric=alert_status)](https://sonarcloud.io/dashboard?id=donghao1393_mcp-dbutils)

<!-- شارات الإصدار والتثبيت -->
[![إصدار PyPI](https://img.shields.io/pypi/v/mcp-dbutils)](https://pypi.org/project/mcp-dbutils/)
[![تنزيلات PyPI](https://img.shields.io/pypi/dm/mcp-dbutils)](https://pypi.org/project/mcp-dbutils/)
[![Smithery](https://smithery.ai/badge/@donghao1393/mcp-dbutils)](https://smithery.ai/server/@donghao1393/mcp-dbutils)

<!-- شارات المواصفات التقنية -->
[![Python](https://img.shields.io/badge/Python-3.10%2B-blue)](https://www.python.org/)
[![الترخيص](https://img.shields.io/github/license/donghao1393/mcp-dbutils)](LICENSE)
[![نجوم GitHub](https://img.shields.io/github/stars/donghao1393/mcp-dbutils?style=social)](https://github.com/donghao1393/mcp-dbutils/stargazers)

[English](README_EN.md) | [中文](README.md) | [Français](README_FR.md) | [Español](README_ES.md) | العربية | [Русский](README_RU.md) | [التوثيق](#التوثيق)

## مقدمة

أدوات قواعد بيانات MCP هي خدمة MCP شاملة تمكّن الذكاء الاصطناعي الخاص بك من إجراء تحليل البيانات من خلال الوصول إلى أنواع متنوعة من قواعد البيانات (SQLite وMySQL وPostgreSQL والمزيد) ضمن تكوين اتصال موحد بطريقة آمنة.

فكر فيها كجسر آمن بين أنظمة الذكاء الاصطناعي وقواعد البيانات الخاصة بك، مما يسمح للذكاء الاصطناعي بقراءة وتحليل بياناتك دون الوصول المباشر إلى قاعدة البيانات أو المخاطرة بتعديلات البيانات.

### الميزات الرئيسية

- **الأمان أولاً**: عمليات للقراءة فقط بشكل صارم، لا وصول مباشر لقاعدة البيانات، اتصالات معزولة، اتصال عند الطلب، مهلات تلقائية
- **ضمانات الخصوصية**: معالجة محلية، الحد الأدنى من كشف البيانات، حماية بيانات الاعتماد، إخفاء البيانات الحساسة
- **دعم قواعد بيانات متعددة**: اتصل بـ SQLite وMySQL وPostgreSQL بنفس الواجهة
- **تكوين بسيط**: ملف YAML واحد لجميع اتصالات قاعدة البيانات الخاصة بك
- **قدرات متقدمة**: استكشاف الجداول، تحليل المخطط، وتنفيذ الاستعلامات

> 🔒 **ملاحظة أمان**: تم بناء أدوات قواعد بيانات MCP بهندسة تضع الأمان في المقام الأول، مما يجعلها مثالية للشركات والشركات الناشئة والأفراد الذين يقدرون حماية البيانات. تعرف على المزيد حول [هندسة الأمان](docs/ar/technical/security.md) لدينا.

## البدء السريع

نقدم طرق تثبيت متعددة، بما في ذلك uvx وDocker وSmithery. للحصول على خطوات تثبيت وتكوين مفصلة، راجع [دليل التثبيت](docs/ar/installation.md).

### الخطوات الأساسية

1. **التثبيت**: اختر طريقة التثبيت المفضلة لديك ([تعليمات مفصلة](docs/ar/installation.md))
2. **التكوين**: قم بإنشاء ملف YAML يحتوي على معلومات اتصال قاعدة البيانات الخاصة بك ([دليل التكوين](docs/ar/configuration.md))
3. **الاتصال**: أضف التكوين إلى عميل الذكاء الاصطناعي الخاص بك
4. **الاستخدام**: ابدأ التفاعل مع قواعد البيانات الخاصة بك ([دليل الاستخدام](docs/ar/usage.md))

## أمثلة على التفاعلات

**أنت**: "هل يمكنك سرد جميع الجداول في قاعدة بيانات my-postgres الخاصة بي؟"

**الذكاء الاصطناعي**: "سأتحقق من ذلك لك. إليك الجداول في قاعدة بيانات my-postgres الخاصة بك:
- العملاء
- المنتجات
- الطلبات
- المخزون
- الموظفون"

**أنت**: "كيف يبدو جدول العملاء؟"

**الذكاء الاصطناعي**: "جدول العملاء له البنية التالية:
- id (عدد صحيح، مفتاح أساسي)
- الاسم (نص)
- البريد الإلكتروني (نص)
- تاريخ_التسجيل (تاريخ)
- آخر_شراء (تاريخ)
- إجمالي_الإنفاق (رقمي)"

**أنت**: "كم عدد العملاء الذين قاموا بعمليات شراء في الشهر الماضي؟"

**الذكاء الاصطناعي**: "دعني أقوم بتشغيل استعلام لمعرفة ذلك... وفقًا للبيانات، قام 128 عميلاً بعمليات شراء في الشهر الماضي. بلغت القيمة الإجمالية لهذه المشتريات 25,437.82 دولارًا."

## الأدوات المتاحة

توفر أدوات قواعد بيانات MCP عدة أدوات يمكن للذكاء الاصطناعي الخاص بك استخدامها:

- **dbutils-list-connections**: يسرد جميع اتصالات قاعدة البيانات المتاحة في التكوين الخاص بك
- **dbutils-list-tables**: يسرد جميع الجداول في قاعدة البيانات
- **dbutils-run-query**: ينفذ استعلام SQL (SELECT فقط)
- **dbutils-get-stats**: يحصل على إحصائيات حول جدول
- **dbutils-list-constraints**: يسرد قيود الجدول
- **dbutils-explain-query**: يحصل على خطة تنفيذ الاستعلام
- **dbutils-get-performance**: يحصل على مقاييس أداء قاعدة البيانات
- **dbutils-analyze-query**: يحلل الاستعلامات للتحسين

## التوثيق

### البدء
- [دليل التثبيت](docs/ar/installation.md) - خطوات تثبيت مفصلة وتعليمات التكوين
- [دليل التثبيت الخاص بالمنصة](docs/ar/installation-platform-specific.md) - تعليمات التثبيت لأنظمة التشغيل المختلفة
- [دليل التكوين](docs/ar/configuration.md) - أمثلة تكوين اتصال قاعدة البيانات وأفضل الممارسات
- [دليل الاستخدام](docs/ar/usage.md) - سير العمل الأساسي وسيناريوهات الاستخدام الشائعة

### التوثيق التقني
- [تصميم الهندسة](docs/ar/technical/architecture.md) - هندسة النظام والمكونات
- [هندسة الأمان](docs/ar/technical/security.md) - ميزات الأمان وآليات الحماية
- [دليل التطوير](docs/ar/technical/development.md) - جودة الكود وسير عمل التطوير
- [دليل الاختبار](docs/ar/technical/testing.md) - إطار الاختبار وأفضل الممارسات
- [تكامل SonarCloud](docs/ar/technical/sonarcloud-integration.md) - دليل تكامل SonarCloud والذكاء الاصطناعي

### توثيق الأمثلة
- [أمثلة SQLite](docs/ar/examples/sqlite-examples.md) - أمثلة عمليات قاعدة بيانات SQLite
- [أمثلة PostgreSQL](docs/ar/examples/postgresql-examples.md) - أمثلة عمليات قاعدة بيانات PostgreSQL
- [أمثلة MySQL](docs/ar/examples/mysql-examples.md) - أمثلة عمليات قاعدة بيانات MySQL
- [تفاعلات LLM المتقدمة](docs/ar/examples/advanced-llm-interactions.md) - أمثلة تفاعل متقدمة مع LLM المختلفة

### الوثائق متعددة اللغات
- **الإنجليزية** - [English Documentation](docs/en/)
- **الصينية** - [中文文档](docs/zh/)
- **الفرنسية** - [Documentation Française](docs/fr/)
- **الإسبانية** - [Documentación en Español](docs/es/)
- **الروسية** - [Документация на русском](docs/ru/)

### الدعم والتعليقات
- [مشكلات GitHub](https://github.com/donghao1393/mcp-dbutils/issues) - الإبلاغ عن المشكلات أو طلب الميزات
- [Smithery](https://smithery.ai/server/@donghao1393/mcp-dbutils) - تثبيت وتحديثات مبسطة

## تاريخ النجوم

[![مخطط تاريخ النجوم](https://starchart.cc/donghao1393/mcp-dbutils.svg?variant=adaptive)](https://starchart.cc/donghao1393/mcp-dbutils)

## الترخيص

هذا المشروع مرخص بموجب ترخيص MIT - راجع ملف [LICENSE](LICENSE) للحصول على التفاصيل.

</div>

==> mcp_dbutils-0.22.0.tar.gz: mcp_dbutils-0.22.0/README_AR.md <==
<div dir="rtl">

# أدوات قواعد بيانات MCP

<!-- شارات حالة المشروع -->
[![حالة البناء](https://img.shields.io/github/workflow/status/donghao1393/mcp-dbutils/Quality%20Assurance?label=tests)](https://github.com/donghao1393/mcp-dbutils/actions)
[![التغطية](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/donghao1393/bdd0a63ec2a816539ff8c136ceb41e48/raw/coverage.json)](https://github.com/donghao1393/mcp-dbutils/actions)
[![حالة بوابة الجودة](https://sonarcloud.io/api/project_badges/measure?project=donghao1393_mcp-dbutils&metric=alert_status)](https://sonarcloud.io/dashboard?id=donghao1393_mcp-dbutils)

<!-- شارات الإصدار والتثبيت -->
[![إصدار PyPI](https://img.shields.io/pypi/v/mcp-dbutils)](https://pypi.org/project/mcp-dbutils/)
[![تنزيلات PyPI](https://img.shields.io/pypi/dm/mcp-dbutils)](https://pypi.org/project/mcp-dbutils/)
[![Smithery](https://smithery.ai/badge/@donghao1393/mcp-dbutils)](https://smithery.ai/server/@donghao1393/mcp-dbutils)

<!-- شارات المواصفات التقنية -->
[![Python](https://img.shields.io/badge/Python-3.10%2B-blue)](https://www.python.org/)
[![الترخيص](https://img.shields.io/github/license/donghao1393/mcp-dbutils)](LICENSE)
[![نجوم GitHub](https://img.shields.io/github/stars/donghao1393/mcp-dbutils?style=social)](https://github.com/donghao1393/mcp-dbutils/stargazers)

[English](README_EN.md) | [中文](README.md) | [Français](README_FR.md) | [Español](README_ES.md) | العربية | [Русский](README_RU.md) | [التوثيق](#التوثيق)

## مقدمة

أدوات قواعد بيانات MCP هي خدمة MCP شاملة تمكّن الذكاء الاصطناعي الخاص بك من إجراء تحليل البيانات من خلال الوصول إلى أنواع متنوعة من قواعد البيانات (SQLite وMySQL وPostgreSQL والمزيد) ضمن تكوين اتصال موحد بطريقة آمنة.

فكر فيها كجسر آمن بين أنظمة الذكاء الاصطناعي وقواعد البيانات الخاصة بك، مما يسمح للذكاء الاصطناعي بقراءة وتحليل بياناتك دون الوصول المباشر إلى قاعدة البيانات أو المخاطرة بتعديلات البيانات.

### الميزات الرئيسية

- **الأمان أولاً**: عمليات للقراءة فقط بشكل صارم، لا وصول مباشر لقاعدة البيانات، اتصالات معزولة، اتصال عند الطلب، مهلات تلقائية
- **ضمانات الخصوصية**: معالجة محلية، الحد الأدنى من كشف البيانات، حماية بيانات الاعتماد، إخفاء البيانات الحساسة
- **دعم قواعد بيانات متعددة**: اتصل بـ SQLite وMySQL وPostgreSQL بنفس الواجهة
- **تكوين بسيط**: ملف YAML واحد لجميع اتصالات قاعدة البيانات الخاصة بك
- **قدرات متقدمة**: استكشاف الجداول، تحليل المخطط، وتنفيذ الاستعلامات

> 🔒 **ملاحظة أمان**: تم بناء أدوات قواعد بيانات MCP بهندسة تضع الأمان في المقام الأول، مما يجعلها مثالية للشركات والشركات الناشئة والأفراد الذين يقدرون حماية البيانات. تعرف على المزيد حول [هندسة الأمان](docs/ar/technical/security.md) لدينا.

## البدء السريع

نقدم طرق تثبيت متعددة، بما في ذلك uvx وDocker وSmithery. للحصول على خطوات تثبيت وتكوين مفصلة، راجع [دليل التثبيت](docs/ar/installation.md).

### الخطوات الأساسية

1. **التثبيت**: اختر طريقة التثبيت المفضلة لديك ([تعليمات مفصلة](docs/ar/installation.md))
2. **التكوين**: قم بإنشاء ملف YAML يحتوي على معلومات اتصال قاعدة البيانات الخاصة بك ([دليل التكوين](docs/ar/configuration.md))
3. **الاتصال**: أضف التكوين إلى عميل الذكاء الاصطناعي الخاص بك
4. **الاستخدام**: ابدأ التفاعل مع قواعد البيانات الخاصة بك ([دليل الاستخدام](docs/ar/usage.md))

## أمثلة على التفاعلات

**أنت**: "هل يمكنك سرد جميع الجداول في قاعدة بيانات my-postgres الخاصة بي؟"

**الذكاء الاصطناعي**: "سأتحقق من ذلك لك. إليك الجداول في قاعدة بيانات my-postgres الخاصة بك:
- العملاء
- المنتجات
- الطلبات
- المخزون
- الموظفون"

**أنت**: "كيف يبدو جدول العملاء؟"

**الذكاء الاصطناعي**: "جدول العملاء له البنية التالية:
- id (عدد صحيح، مفتاح أساسي)
- الاسم (نص)
- البريد الإلكتروني (نص)
- تاريخ_التسجيل (تاريخ)
- آخر_شراء (تاريخ)
- إجمالي_الإنفاق (رقمي)"

**أنت**: "كم عدد العملاء الذين قاموا بعمليات شراء في الشهر الماضي؟"

**الذكاء الاصطناعي**: "دعني أقوم بتشغيل استعلام لمعرفة ذلك... وفقًا للبيانات، قام 128 عميلاً بعمليات شراء في الشهر الماضي. بلغت القيمة الإجمالية لهذه المشتريات 25,437.82 دولارًا."

## الأدوات المتاحة

توفر أدوات قواعد بيانات MCP عدة أدوات يمكن للذكاء الاصطناعي الخاص بك استخدامها:

- **dbutils-list-connections**: يسرد جميع اتصالات قاعدة البيانات المتاحة مع معلومات مفصلة تشمل نوع قاعدة البيانات والمضيف والمنفذ واسم قاعدة البيانات، مع إخفاء المعلومات الحساسة مثل كلمات المرور.
- **dbutils-list-tables**: يسرد جميع الجداول في اتصال قاعدة البيانات المحدد مع أسماء الجداول وعناوين URI والأوصاف المتاحة، مجمعة حسب نوع قاعدة البيانات لسهولة التعرف عليها.
- **dbutils-run-query**: ينفذ استعلامات SQL للقراءة فقط (SELECT فقط) مع دعم للاستعلامات المعقدة، بما في ذلك JOIN وGROUP BY ووظائف التجميع، مع إرجاع نتائج منظمة تتضمن أسماء الأعمدة وصفوف البيانات.
- **dbutils-describe-table**: يوفر معلومات مفصلة عن بنية الجدول، بما في ذلك أسماء الأعمدة وأنواع البيانات وإمكانية الخلو والقيم الافتراضية والتعليقات بتنسيق سهل القراءة.
- **dbutils-get-ddl**: يسترجع بيان DDL (لغة تعريف البيانات) الكامل لإنشاء الجدول المحدد، بما في ذلك جميع تعريفات الأعمدة والقيود والفهارس.
- **dbutils-list-indexes**: يسرد جميع الفهارس على الجدول المحدد، بما في ذلك أسماء الفهارس والأنواع (فريد/غير فريد) وطرق الفهرسة والأعمدة المضمنة، مجمعة حسب اسم الفهرس.
- **dbutils-get-stats**: يسترجع معلومات إحصائية عن الجدول، بما في ذلك العدد التقديري للصفوف ومتوسط طول الصف وحجم البيانات وحجم الفهرس.
- **dbutils-list-constraints**: يسرد جميع القيود على الجدول، بما في ذلك المفاتيح الأساسية والمفاتيح الخارجية والقيود الفريدة وقيود التحقق، مع الجداول والأعمدة المرجعية للمفاتيح الخارجية.
- **dbutils-explain-query**: يوفر خطة تنفيذ لاستعلام SQL، موضحًا كيف سيعالج محرك قاعدة البيانات الاستعلام، بما في ذلك طرق الوصول وأنواع الربط والتكاليف المقدرة.
- **dbutils-get-performance**: يسترجع مقاييس الأداء لاتصال قاعدة البيانات، بما في ذلك عدد الاستعلامات ومتوسط وقت التنفيذ واستخدام الذاكرة وإحصاءات الأخطاء.
- **dbutils-analyze-query**: يحلل خصائص أداء استعلام SQL، مع توفير خطة التنفيذ ووقت التنفيذ الفعلي وتوصيات محددة للتحسين.

لمزيد من الوصف التفصيلي وأمثلة استخدام هذه الأدوات، راجع [دليل الاستخدام](docs/ar/usage.md).

## التوثيق

### البدء
- [دليل التثبيت](docs/ar/installation.md) - خطوات تثبيت مفصلة وتعليمات التكوين
- [دليل التثبيت الخاص بالمنصة](docs/ar/installation-platform-specific.md) - تعليمات التثبيت لأنظمة التشغيل المختلفة
- [دليل التكوين](docs/ar/configuration.md) - أمثلة تكوين اتصال قاعدة البيانات وأفضل الممارسات
- [دليل الاستخدام](docs/ar/usage.md) - سير العمل الأساسي وسيناريوهات الاستخدام الشائعة

### التوثيق التقني
- [تصميم الهندسة](docs/ar/technical/architecture.md) - هندسة النظام والمكونات
- [هندسة الأمان](docs/ar/technical/security.md) - ميزات الأمان وآليات الحماية
- [دليل التطوير](docs/ar/technical/development.md) - جودة الكود وسير عمل التطوير
- [دليل الاختبار](docs/ar/technical/testing.md) - إطار الاختبار وأفضل الممارسات
- [تكامل SonarCloud](docs/ar/technical/sonarcloud-integration.md) - دليل تكامل SonarCloud والذكاء الاصطناعي

### توثيق الأمثلة
- [أمثلة SQLite](docs/ar/examples/sqlite-examples.md) - أمثلة عمليات قاعدة بيانات SQLite
- [أمثلة PostgreSQL](docs/ar/examples/postgresql-examples.md) - أمثلة عمليات قاعدة بيانات PostgreSQL
- [أمثلة MySQL](docs/ar/examples/mysql-examples.md) - أمثلة عمليات قاعدة بيانات MySQL
- [تفاعلات LLM المتقدمة](docs/ar/examples/advanced-llm-interactions.md) - أمثلة تفاعل متقدمة مع LLM المختلفة

### الوثائق متعددة اللغات
- **الإنجليزية** - [English Documentation](docs/en/)
- **الصينية** - [中文文档](docs/zh/)
- **الفرنسية** - [Documentation Française](docs/fr/)
- **الإسبانية** - [Documentación en Español](docs/es/)
- **الروسية** - [Документация на русском](docs/ru/)

### الدعم والتعليقات
- [مشكلات GitHub](https://github.com/donghao1393/mcp-dbutils/issues) - الإبلاغ عن المشكلات أو طلب الميزات
- [Smithery](https://smithery.ai/server/@donghao1393/mcp-dbutils) - تثبيت وتحديثات مبسطة

## تاريخ النجوم

[![مخطط تاريخ النجوم](https://starchart.cc/donghao1393/mcp-dbutils.svg?variant=adaptive)](https://starchart.cc/donghao1393/mcp-dbutils)

## الترخيص

هذا المشروع مرخص بموجب ترخيص MIT - راجع ملف [LICENSE](LICENSE) للحصول على التفاصيل.

</div>
